/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef CMDGRID_H

#define CMDGRID_H

#include <shellp/shellcommand.h>
#include <shellp/shellcmdrealarg.h>
#include <shellp/shellcmdintarg.h>
#include <shellp/shellcmdboolarg.h>
#include <shellp/shellcmdstringarg.h>

namespace grale
{
	class Grid;
}

class CmdGridNewUniform : public shellp::ShellCommand
{
public:
	CmdGridNewUniform(const std::string &cmdname);
	~CmdGridNewUniform();
	bool execute();
private:
	shellp::ShellCmdRealArg *centerxarg, *centeryarg, *sizearg;
	shellp::ShellCmdIntArg *subdivarg;
	shellp::ShellCmdStringArg *m_pGridName;
};

class CmdGridNewLens : public shellp::ShellCommand
{
public:
	CmdGridNewLens(const std::string &cmdname);
	~CmdGridNewLens();
	bool execute();
private:
	shellp::ShellCmdRealArg *centerxarg, *centeryarg, *sizearg;
	shellp::ShellCmdIntArg *minsquaresarg, *maxsquaresarg;
	shellp::ShellCmdIntArg *xintarg, *yintarg;
	shellp::ShellCmdBoolArg *m_pIgnoreSheet, *m_pKeepLargerArg;
	shellp::ShellCmdStringArg *m_pGridName;
};

class CmdGridPlot : public shellp::ShellCommand
{
public:
	CmdGridPlot(const std::string &cmdName);
	~CmdGridPlot();
	bool execute();
private:
	bool plotGrid(FILE *pFile, const std::string &name, const grale::Grid *pGrid);

	shellp::ShellCmdStringArg *m_pFileNameArg;
};

class CmdGridList : public shellp::ShellCommand
{
public:
	CmdGridList(const std::string &cmdName);
	~CmdGridList();
	bool execute();
};

class CmdGridClear : public shellp::ShellCommand
{
public:
	CmdGridClear(const std::string &cmdName);
	~CmdGridClear();
	bool execute();
private:
	shellp::ShellCmdStringArg *m_pName;
	shellp::ShellCmdBoolArg *m_pSureArg;
};

class CmdGridClearAll : public shellp::ShellCommand
{
public:
	CmdGridClearAll(const std::string &cmdName);
	~CmdGridClearAll();
	bool execute();
private:
	shellp::ShellCmdBoolArg *m_pSureArg;
};

#endif // CMDGRID_H

